Coverage for src/expo_notifications/models/receipt.py: 100%

1 from django.db import models

2

3

4 class Receipt(models.Model):

5 ticket = models.ForeignKey(

6 to="expo_notifications.Ticket",

7 on_delete=models.CASCADE,

8 related_name="receipts",

9 )

10

11 is_success = models.BooleanField()

12

13 error_message = models.TextField(

14 blank=True,

15 )

16

17 date_checked = models.DateTimeField()

18

19 def __str__(self) -> str:

20 return f"Receipt #{self.pk}"